<?php
/**
 * Plugin Name: Skrill - JTL Shop
 * Plugin URI:  http://www.skrill.com/
 * Description: JTL Shop with Skrill payment gateway
 * Author:      Skrill
 * Author URI:  hhttp://www.skrill.com/
 *
 * @package Skrill
 */

/**
 * Copyright (c) Skrill
 */

include_once(PFAD_ROOT . PFAD_INCLUDES_MODULES . 'PaymentMethod.class.php');
include_once(dirname(__FILE__).'/core.php');

class Skrill extends PaymentMethod
{
    const PROCESSED_STATUS = 2;
    const PENDING_STATUS = 0;
    const FAILED_STATUS = -2;
    const REFUND_STATUS = -4;
    const REFUND_FAILED_STATUS = -5;
    const REFUND_PENDING_STATUS = -6;
    const FRAUD_STATUS = -7;
    const NOT_VERIFIED_STATUS = -8;

    public function init($nAgainCheckout = 0)
    {
        parent::init($nAgainCheckout);
        // set name for payment method.
        $this->name = substr($this->moduleID, strripos($this->moduleID, '_') + 1);
        $this->paymentMethod = 'skrill_'.$this->name;
    }

    public function getPaymentType()
    {
        $paymentType = array(
            'allekartenundalternativenzahlungsmethoden' => 'FLEXIBLE',
            'skrillwallet' => 'WLT',
            'paysafecard' => 'PSC',
            'kreditkarte' => 'ACC',
            'visa' => 'VSA',
            'mastercard' => 'MSC',
            'maestro' => 'MAE',
            'rapidtransfer(onlinebanktransfer)' => 'OBT',
            'giropay' => 'GIR',
            'klarna' => 'SFT',
            'ideal' => 'IDL',
            'poli' => 'PLI',
            'przelewy24' => 'PWY',
            'epay.bg' => 'EPY',
            'alipay' => 'ALI',
            'neteller' => 'NTL',
            'barzahlung/rechnung' => 'ACI',
            'bankuberweisung' => 'ADB',
            'manuellebankuberweisung' => 'AOB',
            'paysafecash' => 'PCH',
            'blik' => 'BLK'
        );
        return $paymentType[$this->name];
    }

    private function getConfig($key)
    {
        global $oPlugin;

        if (isset($oPlugin->oPluginEinstellungAssoc_arr[$this->moduleID.'_'.$key])) {
            return $oPlugin->oPluginEinstellungAssoc_arr[$this->moduleID.'_'.$key];
        }
        return '';
    }

    private function getConfigGeneral($key)
    {
        global $oPlugin;

        if (!$oPlugin) {
            $oPlugin = Plugin::getPluginById('jtl_skrill');
        }

        return $oPlugin->oPluginEinstellungAssoc_arr['skrill_setting_'.$key];
    }

    protected function getSkrillModulId()
    {
        global $oPlugin;

        $name = str_replace('skrill_', '', $this->paymentMethod);
        return 'kPlugin_'.$oPlugin->kPlugin.'_'.$name;
    }

    protected function getStatusUrl($hash, $amount)
    {
        global $DB;

        $key = ($this->duringCheckout) ? 'sh' : 'ph';
        $cleanHash = $hash[0] == '_' ? substr($hash, 1) : $hash;

        if ($this->duringCheckout) {
            $sessionSave = $DB->select(
                'tzahlungsession',
                'cZahlungsID',
                $cleanHash,
                null,
                null,
                null,
                null,
                false,
                'dZeit'
            );
            $date = $sessionSave->dZeit;
        } else {
            $sessionSave = Shop::DB()->select(
                'tzahlungsid',
                'cId',
                $cleanHash,
                null,
                null,
                null,
                null,
                false,
                'dDatum'
            );
            $date = $sessionSave->dDatum;
        }

        $hashAntiFraud = SkrillPayment::generateHashAntiFraud($amount, $hash, $date);

        $statusUrl = Shop::getURL(true) . '/includes/modules/notify.php?' . $key . '=' . $hash .
            '&is_status_url=1&skrillModulId='.$this->getSkrillModulId().'&secure_payment='.$hashAntiFraud;
        return $statusUrl;
    }

    /**
     * provide url to process response from gateway when do refund
     *
     * @param   $mbTransactionId string
     * @param   $transactionKey string
     *
     * @return  string
     */
    protected function getRefundStatusUrl($mbTransactionId, $transactionKey)
    {
        global $oPlugin, $DB;

        $result = Shop::DB()->select('xplugin_jtl_skrill_orders', 'mb_transaction_id', $mbTransactionId);
        $refundStatusUrl = Shop::getURL(true) . '/includes/plugins/jtl_skrill/version/'.$oPlugin->nVersion.
            '/frontend/refund_status_url.php?orderId=' . $result->order_id .
            '&skrillModulId='.$this->getSkrillModulId().'&transactionKey='.$transactionKey;

        return $refundStatusUrl;
    }

    public function preparePaymentProcess($order)
    {
        global $oPlugin, $smarty;

        $hash = $this->generateHash($order, 32);
        $_SESSION['transaction_id'] = $hash;

        $skrillSettings = $this->getSkrillSettings();
        if (empty($skrillSettings['merchant_id']) ||
            empty($skrillSettings['merchant_account']) ||
            empty($skrillSettings['api_passwd']) ||
            empty($skrillSettings['secret_word'])) {
                Jtllog::writeLog('Skrill checkout required mandatory parameters', JTLLOG_LEVEL_ERROR);
                $this->redirectError('ERROR_GENERAL_REDIRECT');
        }
        $checkoutParameters['pay_to_email'] = $skrillSettings['merchant_account'];
        $checkoutParameters['recipient_description'] = $skrillSettings['recipient_desc'];
        $checkoutParameters['transaction_id'] = substr($hash, 1);
        $checkoutParameters['return_url'] =
            $this->getNotificationURL($hash).'&skrillModulId='.$this->getSkrillModulId();
        $checkoutParameters['status_url'] = $this->getStatusUrl($hash, $order->fGesamtsumme);
        if (!empty($skrillSettings['merchant_email'])) {
            $checkoutParameters['status_url2'] = 'mailto:'.$skrillSettings['merchant_email'];
        }
        $checkoutParameters['cancel_url'] = gibShopURL().'/bestellvorgang.php?editZahlungsart=1';
        $checkoutParameters['language'] = strtoupper($this->getLangCode());
        $checkoutParameters['logo_url'] = $skrillSettings['logo_url'];
        $checkoutParameters['prepare_only'] = 1;
        $checkoutParameters['pay_from_email'] = $order->oRechnungsadresse->cMail;
        $checkoutParameters['firstname'] = $order->oRechnungsadresse->cVorname;
        $checkoutParameters['lastname'] = $order->oRechnungsadresse->cNachname;
        $checkoutParameters['address'] = $order->oRechnungsadresse->cStrasse.' '.$order->oRechnungsadresse->cHausnummer;
        $checkoutParameters['postal_code'] = $order->oRechnungsadresse->cPLZ;
        $checkoutParameters['city'] = $order->oRechnungsadresse->cOrt;
        $checkoutParameters['country'] = SkrillPayment::getCountryIso3ByIso2($order->oRechnungsadresse->cLand);
        $checkoutParameters['amount'] = $order->fGesamtsumme;
        $checkoutParameters['currency'] = $order->Waehrung->cISO;
        $checkoutParameters['merchant_fields'] = 'platform,plugin_version';
        $checkoutParameters['platform'] = '21477226';
        $checkoutParameters['plugin_version'] = $oPlugin->nVersion;

        $checkoutParameters['detail1_description'] = "Payment to";
        $checkoutParameters['detail1_text'] = $skrillSettings['recipient_desc'];
        $checkoutParameters['detail2_description'] = "Order Amount";
        $checkoutParameters['detail2_text'] = $this->setFormatNumber(
            $order->fWarensummeKundenwaehrung
        ).' '.$order->Waehrung->cISO;

        $shipping = $order->fVersandKundenwaehrung;
        if (!empty($shipping)) {
            $checkoutParameters['detail3_description'] = "Shipping Tax";
            $checkoutParameters['detail3_text'] = $this->setFormatNumber($shipping).' '.$order->Waehrung->cISO;
        }

        if ($this->name != "allekartenundalternativenzahlungsmethoden") {
            if ($this->getPaymentType() == 'ACC') {
                $paymentMethods = 'VSA,MSC';
            } else {
                $paymentMethods = $this->getPaymentType();
            }
            $checkoutParameters['payment_methods'] = $paymentMethods;
        }
        $skrillPaymentUrl = SkrillPayment::getPaymentUrlByCheckoutParameters($checkoutParameters);

        if ($skrillPaymentUrl) {
            $_SESSION['skrillPaymentUrl'] = $skrillPaymentUrl;
            if ($this->duringCheckout) {                
                $header = 'Location: ' . $skrillPaymentUrl;
                header($header);
                exit();                
            } else {
                $header = 'Location: ' . gibShopURL().'/'.$this->getCheckoutPageLink();
                header($header);
                exit();
            }
        } else {
            Jtllog::writeLog('Skrill checkout get sid failed', JTLLOG_LEVEL_ERROR);
            $this->redirectError('ERROR_GET_SID');
        }
    }

    /**
     * set formated number with 2 digits
     * @param string $number
     */
    public function setFormatNumber($number)
    {
        $number = (float) str_replace(',', '.', $number);
        return number_format($number, 2, '.', '');
    }

    /**
     * return checkout page link based on current session language
     * @return string
     */
    public function getCheckoutPageLink()
    {
        $result = Shop::DB()->query(
            "SELECT b.cSeo FROM tlink a
            LEFT JOIN tlinksprache b
            ON (a.kLink = b.kLink)
            WHERE b.cISOSprache = '".$_SESSION['cISOSprache']."'
            AND a.cName = 'skrill checkout page' 
            order by a.kLink desc",
            1
        );

        return $result->cSeo;
    }

    /**
     * return pending payment page link based on current session language
     * @return string
     */
    public static function getPendingPageLink()
    {
        $result = Shop::DB()->query(
            "SELECT b.cSeo FROM tlink a
            LEFT JOIN tlinksprache b
            ON (a.kLink = b.kLink)
            WHERE b.cISOSprache = '".$_SESSION['cISOSprache']."'
            AND a.cName = 'pending payment' 
            order by a.kLink desc",
            1
        );

        return $result->cSeo;
    }

    /**
    * do update order after get response from gateway
    *
    * @param object $order
    * @param string $paymentHash
    * @param array  $args
    */
    public function handleNotification($order, $paymentHash, $args)
    {
        global $DB;

        if (!isset($args['is_status_url'])) {
            sleep(5);
            $_SESSION['skrillOrder'] = $order;

            $this->updateOrderStatus($order->kBestellung, $_SESSION['skrill_status']);
            unset($_SESSION['skrill_status']);

            $query = "UPDATE xplugin_jtl_skrill_orders SET order_id = '"
                .intval($order->kBestellung)."' WHERE transaction_id = '".$DB->escape($args['transaction_id'])."'";
            $DB->executeQuery($query, 4);

            $header = 'Location: ' . gibShopURL().'/'.Skrill::getPendingPageLink().
            '?error='.FRONTEND_MESSAGE_PLEASE_BACK_AGAIN;
            header($header);
            exit();
        }

        if (isset($_SESSION['skrill_status']) && $_SESSION['skrill_status'] == self::PENDING_STATUS) {
            $this->updateOrderStatus($order->kBestellung, $_SESSION['skrill_status']);
            unset($_SESSION['skrill_status']);
            $this->redirectError('FRONTEND_MESSAGE_PLEASE_BACK_AGAIN');
        } else {
            $skrillOrder = new stdClass();
            $skrillOrder->order_id  = $order->kBestellung;
            Shop::DB()->update(
                'xplugin_jtl_skrill_orders',
                'mb_transaction_id',
                $args['mb_transaction_id'],
                $skrillOrder
            );

            $result =  Shop::DB()->select('xplugin_jtl_skrill_orders', 'mb_transaction_id', $args['mb_transaction_id']);
            $paymentStatus = unserialize($result->payment_status);
            $this->updateOrderStatus($order->kBestellung, $paymentStatus['status']);

            Jtllog::writeLog(
                'Skrill status url update order status : order id = ' . $order->kBestellung .
                 '; status : '.$paymentStatus['status'],
                JTLLOG_LEVEL_NOTICE
            );

            $_SESSION['transaction_id'] = '';
            $_SESSION['cZahlungs_id'] = $_REQUEST['sh'];

            $this->sendConfirmationMail($order);

            $incomingPayment = new stdClass();
            $incomingPayment->fBetrag = $order->fGesamtsumme;
            $incomingPayment->cISO = $order->Waehrung->cISO;
            $incomingPayment->cZahler = $this->getPaymentType();
            $incomingPayment->cHinweis = $args['mb_transaction_id'];
            $this->addIncomingPayment($order, $incomingPayment);

            exit;
        }
    }

    private function getCountryNameByCountryIso($countryIso)
    {
        global $DB;

        if (strlen($countryIso) == 3) {
            $countryIso = SkrillPayment::getCountryIso2ByIso3($countryIso);
        }

        $result = Shop::DB()->query("select cDeutsch as cName from tland where cISO = '".$countryIso."'", 1);

        if ($result) {
            return $result->cName;
        }
        return '';
    }

    private function getSkrillOrderFields($paymentResult)
    {
        Jtllog::writeLog('session cisosparche : ' . $_SESSION['cISOSprache'], JTLLOG_LEVEL_NOTICE);

        $fields = $paymentResult;

        $paymentType = '';
        if (isset($paymentResult['payment_type'])) {
            $paymentType = $this->getTranslate('SKRILL_FRONTEND_PM_'.$paymentResult['payment_type']);
        }

        $orderOriginatedFrom = '';
        if (isset($paymentResult['ip_country'])) {
            $orderOriginatedFrom = $this->getCountryNameByCountryIso($paymentResult['ip_country']);
        }

        $cardIssuerCountry = '';
        if (isset($paymentResult['payment_instrument_country'])) {
            $cardIssuerCountry = $this->getCountryNameByCountryIso($paymentResult['payment_instrument_country']);
        }
        $status = $paymentResult['status'];
        $statusTranslation = $this->getTranslateForceGER($this->getTransactionStatusIdentifier($status));

        $fields['payment_method'] = $this->paymentMethod;
        $fields['payment_type'] = $paymentType;
        $fields['order_originated_from'] = $orderOriginatedFrom;
        $fields['card_issuer_country'] = $cardIssuerCountry;
        $fields['status'] = $statusTranslation;
        $fields['payment_status'] = serialize($paymentResult);

        return $fields;
    }

    /**
     * insert response from gateway to table xplugin_jtl_skrill_orders
     *
     * @param   array $paymentResult(mb_transaction_id, transaction_id, payment_method, payment_type,
     *                order_originated_from, card_issuer_country, mb_amount, mb_currency, status,
     *                payment_status, pay_from_email)
     */
    public function addSkrillOrder($paymentResult)
    {
        $fields = $this->getSkrillOrderFields($paymentResult);
        $object = new stdClass();
        $object->mb_transaction_id = $fields['mb_transaction_id'];
        $object->transaction_id = $fields['transaction_id'];
        $object->payment_method = $fields['payment_method'];
        $object->payment_type = $fields['payment_type'];
        $object->order_originated_from = $fields['order_originated_from'];
        $object->card_issuer_country = $fields['card_issuer_country'];
        $object->amount = $fields['mb_amount'];
        $object->currency = $fields['mb_currency'];
        $object->status = $fields['status'];
        $object->payment_status = $fields['payment_status'];
        $object->pay_from_email = $fields['pay_from_email'];

        Shop::DB()->insert('xplugin_jtl_skrill_orders', $object);
    }


    /**
     * update data in table xplugin_jtl_skrill_orders use response data from gateway
     *
     * @param   array $paymentResult(mb_transaction_id, transaction_id, payment_method, payment_type,
     *                order_originated_from, card_issuer_country, mb_amount, mb_currency, status,
     *                payment_status, pay_from_email)
     */
    public function updateSkrillOrder($paymentResult)
    {
        $fields = $this->getSkrillOrderFields($paymentResult);
        $object = new stdClass();
        $object->mb_transaction_id = $fields['mb_transaction_id'];
        $object->transaction_id = $fields['transaction_id'];
        $object->payment_method = $fields['payment_method'];
        $object->payment_type = $fields['payment_type'];
        $object->order_originated_from = $fields['order_originated_from'];
        $object->card_issuer_country = $fields['card_issuer_country'];
        $object->amount = $fields['mb_amount'];
        $object->currency = $fields['mb_currency'];
        $object->status = $fields['status'];
        $object->payment_status = $fields['payment_status'];
        $object->pay_from_email = $fields['pay_from_email'];

        Shop::DB()->update('xplugin_jtl_skrill_orders', $object);
    }

    /**
     * return true if order already created
     *
     * @param string $transactionId
     */
    public function isSkrillOrderExist($transactionId)
    {
        $result =  Shop::DB()->select('xplugin_jtl_skrill_orders', 'transaction_id', $transactionId);

        if ($result) {
            return true;
        }

        return false;
    }

    /**
     * return true if order already created
     *
     * @param Bestellung $order
     * @param string     $hash
     * @param array      $args
     * @return boolean
     */
    public function finalizeOrder($order, $hash, $args)
    {
        global $DB;

        if ($order->cStatus == BESTELLUNG_STATUS_STORNO) {
            $paymentResult = Shop::DB()->select('xplugin_jtl_skrill_orders', 'order_id', $order->kBestellung);
            $paymentStatus = unserialize($paymentResult->payment_status);
            $errorIdentifier = SkrillPayment::getSkrillErrorMapping($paymentStatus['status']);
            Jtllog::writeLog('Skrill return url redirect error', JTLLOG_LEVEL_ERROR);
            $this->redirectError($errorIdentifier);
        }

        if (isset($args['is_status_url']) && isset($args['mb_transaction_id'])) {
            return true;
        }

        /* return_url */
        Jtllog::writeLog('Skrill status url late', JTLLOG_LEVEL_NOTICE);
        $_SESSION['skrill_status'] = self::PENDING_STATUS;
        return true;
    }

    public function redirectError($errorIdentifier)
    {
        $header = 'Location: ' . gibShopURL() . '/bestellvorgang.php?editZahlungsart=1&error='.$errorIdentifier;
        header($header);
        exit();
    }

    public function getTransactionStatusIdentifier($status)
    {
        return SkrillPayment::getTransactionStatus($status);
    }

    /**
     * send request to gateway to do refund
     *
     * @param   $cOrderId string
     * @return  string
     */
    public function doBackendRefund($cOrderId)
    {
        global $DB;

        $skrillSettings = $this->getSkrillSettings();
        $order = Shop::DB()->select('xplugin_jtl_skrill_orders', 'order_id', intval($cOrderId));
        $paymentStatus = unserialize($order->payment_status);

        $transactionParameters['email'] = $skrillSettings['merchant_account'];
        $transactionParameters['password'] = $skrillSettings['api_passwd'];
        $transactionParameters['mb_transaction_id'] = $order->mb_transaction_id;
        $transactionParameters['amount'] = $order->amount;
        $transactionParameters['refund_status_url'] = $this->getRefundStatusUrl(
            $order->mb_transaction_id,
            $paymentStatus['md5sig']
        );
        Jtllog::writeLog(
            'refund parameters :  ' . print_r($transactionParameters, true),
            JTLLOG_LEVEL_NOTICE
        );

        $result = SkrillPayment::doRefund($transactionParameters);
        Jtllog::writeLog(
            'response from gateway : '.print_r($result, true),
            JTLLOG_LEVEL_NOTICE
        );

        if (!property_exists($result, 'status')) {
            return $result;
        } elseif ((int)$result->status === self::PROCESSED_STATUS) {
            $orderStatusId = self::REFUND_STATUS;
            $orderStatusName = $this->getTranslateForceGER($this->getTransactionStatusIdentifier($orderStatusId));
            $object = new stdClass();
            $object->status  = $orderStatusName;
            Shop::DB()->update('xplugin_jtl_skrill_orders', 'order_id', intval($cOrderId), $object);
            $this->updateOrderStatus($cOrderId, $orderStatusId);

            return self::PROCESSED_STATUS;
        } elseif ((int)$result->status === self::PENDING_STATUS) {
            $orderStatusId = self::REFUND_PENDING_STATUS;
            $orderStatusName = $this->getTranslateForceGER($this->getTransactionStatusIdentifier($orderStatusId));
            $object = new stdClass();
            $object->status  = $orderStatusName;
            Shop::DB()->update('xplugin_jtl_skrill_orders', 'order_id', intval($cOrderId), $object);
            $this->updateOrderStatus($cOrderId, $orderStatusId);
            return self::PENDING_STATUS;
        } else {
            return $this->getTransactionStatusIdentifier((int)$result->status);
        }
    }

    /**
     * get current payment status from gateway then update order status
     *
     * @param   $cOrderId string
     * @return  string
     */
    public function doUpdateStatus($cOrderId)
    {
        global $DB;

        $order = Shop::DB()->select('xplugin_jtl_skrill_orders', 'order_id', intval($cOrderId));

        $skrillSettings = $this->getSkrillSettings();
        $paymentParameters['email'] = $skrillSettings['merchant_account'];
        $paymentParameters['password'] = $skrillSettings['api_passwd'];
        $paymentParameters['action'] = 'status_trn';
        $paymentParameters['trn_id'] = $order->transaction_id;

        $result = SkrillPayment::getStatusTrn($paymentParameters);


        if ($result == 'CANNOT_LOGIN' || $result == 'ACCOUNT_LOCKED' || $result == 'GENERAL_ERROR') {
            return $result;
        }

        $isCredentialValid = SkrillPayment::isCredentialValid($skrillSettings, $result);
        if (!$isCredentialValid) {
            return self::NOT_VERIFIED_STATUS;
        } else {
            $statusResult['paymentType'] = '';
            if (isset($result['payment_type'])) {
                $statusResult['paymentType'] = $this->getTranslate('SKRILL_FRONTEND_PM_'.$result['payment_type']);
            }

            $statusResult['orderOriginatedFrom'] = '';
            if (isset($result['ip_country'])) {
                $statusResult['orderOriginatedFrom'] = $this->getCountryNameByCountryIso($result['ip_country']);
            }

            $statusResult['cardIssuerCountry'] = '';
            if (isset($result['payment_instrument_country'])) {
                $statusResult['cardIssuerCountry'] =
                    $this->getCountryNameByCountryIso($result['payment_instrument_country']);
            }
            $status = $result['status'];
            $statusResult['statusWord'] = $this->getTranslateForceGER($this->getTransactionStatusIdentifier($status));

            $order = new stdClass();
            $order->status  = $statusResult['statusWord'];
            $order->payment_type  = $statusResult['paymentType'];
            $order->order_originated_from  = $statusResult['orderOriginatedFrom'];
            $order->card_issuer_country  = $statusResult['cardIssuerCountry'];
            Shop::DB()->update('xplugin_jtl_skrill_orders', 'order_id', intval($cOrderId), $order);

            $this->updateOrderStatus($cOrderId, $status);
            return self::PROCESSED_STATUS;
        }
    }

    /**
     * change order status base on response from gateway
     *
     * @param   $kBestellung string
     * @param   $status string
     * @return  string
     */
    public function updateOrderStatus($kBestellung, $status)
    {
        switch ($status) {
            case '2':
                $order = new stdClass();
                $order->kBestellung = $kBestellung;
                $this->setOrderStatusToPaid($order);
                break;
            case '-7': // fraud
                $status = 'BACKEND_TT_FRAUD';
                $order = new stdClass();
                $order->kBestellung = $kBestellung;
                $this->setOrderStatusToPaid($order);
                break;
            case '-8': // Not Verified
                $status = 'GENERAL_TEXT_NOT_VERIFIED';
                $order = new stdClass();
                $order->kBestellung = $kBestellung;
                $this->setOrderStatusToPaid($order);
                break;
            case '0':
                $_upd = new stdClass();
                $_upd->cStatus = BESTELLUNG_STATUS_OFFEN;
                $_upd->dBezahltDatum = 'now()';
                Shop::DB()->update('tbestellung', 'kBestellung', $kBestellung, $_upd);
                break;
            case '-1':
            case '-2':
            case '-3':
            case '-4':
                $this->cancelOrder($kBestellung);
                break;
            case '-5':
                $status = 'BACKEND_TT_REFUNDED_FAILED';
                break;
            default:
                $status = 'ERROR_GENERAL_ABANDONED_BYUSER';
                break;
        }
    }

    private function getTranslate($identifier)
    {
        global $oPlugin;

        if (!$oPlugin) {
            $oPlugin = Plugin::getPluginById('jtl_skrill');
        }

        if (isset($oPlugin->oPluginSprachvariableAssoc_arr[$identifier])) {
            return $oPlugin->oPluginSprachvariableAssoc_arr[$identifier];
        }
        return $identifier;
    }

    public function getTranslateForceGER($identifier)
    {
        global $oPlugin;

        if (!$oPlugin) {
            $oPlugin = Plugin::getPluginById('jtl_skrill');
        }

        $oSprache = gibStandardsprache();
        $oPluginSprarch = gibPluginSprachvariablen($oPlugin->kPlugin, $oSprache->cISO);

        if (isset($oPluginSprarch[$identifier])) {
            return $oPluginSprarch[$identifier];
        }
        return $identifier;
    }

    private function getLangCode()
    {
        $langCode = convertISO2ISO639($_SESSION['cISOSprache']);

        if (!$langCode) {
            $langCode = "en";
        }
        
        return $langCode;
    }

    public function getSkrillSettings()
    {
        $skrillSettings = array(
            'merchant_id'  => $this->getConfigGeneral('merchant_id'),
            'merchant_account' => $this->getConfigGeneral('merchant_account'),
            'recipient_desc'    => $this->getConfigGeneral('recipient_desc'),
            'logo_url'    => $this->getConfigGeneral('logo_url'),
            'api_passwd'    => md5($this->getConfigGeneral('api_passwd')),
            'secret_word'    => md5($this->getConfigGeneral('secret_word')),
            'merchant_email' => $this->getConfigGeneral('merchant_email')
        );

        return $skrillSettings;
    }

    private function getMerchantEmail()
    {
        global $DB;

        $merchant_account = $this->getConfigGeneral('merchant_account');
        if ($merchant_account) {
            return $merchant_account;
        }
        $email = Shop::DB()->select(
            'tadminlogin',
            'kAdminlogingruppe',
            1,
            'bAktiv',
            1
        );
        return $email->cMail;
    }
}
